#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import time

YELLOW = '1;33;40'
GREEN = '1;32;40'
RED = '1;31;40'


def cprint(msg, color=None):
    if not color:
        sys.stdout.write('{msg}'.format(c=color, msg=msg))
    else:
        sys.stdout.write('\x1b[{c}m{msg}\x1b[0m'.format(c=color, msg=msg))


def typewrite(msg, delay, color=None):
    for char in msg:
        cprint(char, color)
        sys.stdout.flush()
        time.sleep(delay)
    sys.stdout.write(os.linesep)


def log(msg, delay=0.3, color=YELLOW):
    cprint(msg, color)
    sys.stdout.write(os.linesep)
    sys.stdout.flush()
    time.sleep(delay)


def narrator(msg, delay=0.05):
    typewrite(msg, delay)
    time.sleep(1)


def cmd(msg, delay=0.02):
    typewrite(msg, delay, RED)
    time.sleep(0.1)


def pause(delay=1):
    time.sleep(delay)


def clear():
    os.system('clear')


def run():
    styles = {
        'type': narrator,
        'log': log,
        'cmd': cmd,
    }

    commands = {'pause': pause,
                'clear': clear}

    style = typewrite
    command = None
    delay = None
    with open('swipt/people/carlos.txt') as fn:
        for line in (line.strip() for line in fn.readlines()):
            # Parse styles
            if line.startswith('#'):
                args = line.split('#')
                if len(args) > 1 and styles.get(args[1]):
                    style = styles.get(args[1])
                    if len(args) > 2:
                        delay = float(args[2])
                    else:
                        delay = None
                continue
            # Parse commands
            if line.startswith('>'):
                args = line.split('>')
                if len(args) > 1 and commands.get(args[1]):
                    command = commands.get(args[1])
                    command()
                continue

            if not delay:
                style(line)
            else:
                style(line, delay)

run()



# - *- coding: utf- 8 - *-
def run():
    import sys
    import traceback 


    list_question_response = [
        ('Examen de aleman!! Introduce las respuestas despues de cada mensaje y pulsa INTRO!', '', '', ''),
        ('Moneda de Alemania antes del Euro', 'Marco', 'No, en castellano no, en Aleman :)', 'No, en castellano no, en Aleman :)'),
        ('', 'Rahmen', 'Correcto aunque esa palabra no se si selvirá para mucho', 'No es correcto, es rahmen, pero vamos que tampoco te servira de mucho'),
        ('Palabra más dificil de pronunciar en alemán (ardilla)', 'herrschst ', 'HERRSCHST, (un audio al grupo para ver como suena)', 'HERRSCHST, un audio al grupo para ver como suena'),
        ('En alemania en un coche cual es la rueda que menos vueltas da en una curva', 'repuesto', 'Esa era chunga','Esa era chunga'),
        ('Bueno, la última¿ Que significa Omelett?', 'Tortilla de papas','Correcto','No es correcto, significa Tortilla de papas')
    ]

    mensaje =' *****  Muchas gracias por todo los ratos que hemos pasado, por toda la paciencia que has tenido y por todo lo que me has ensenado. Te deseo lo mejor un abrazo muy fuerte****. \n'

    try:
        for i in range(0, len(list_question_response)):
            print list_question_response[i][0]
            response = raw_input()

            print response

            if list_question_response[i][1].lower() == response.lower():
                print list_question_response[i][2]
            else:
                print list_question_response[i][3]

            print '\n'

    except:
        print 'ERROR: Ya has pulsado alguna tecla de esas chungas del aleman y lo has roto'

    print mensaje

run()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
jessi.py

Script that probably do something in python (in an efficient way or not... who knows it :P)
(As you can see I have not forgotten to add documentation)

Created by Jessica Fernandez on 2017-03
'''
import time


class Jessi(object):
    """ Class that may makes you smile :) """

    def __init__(self, *args, **kwargs):
        """ Initializes the most important attributes """
        self.leg_list = ('a_leg', 'r_leg', 'b_leg')
        self.madrid_to_berlin_call = {
            'a_leg': (0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 3, 0, 4, 0, 5, 0),
            'r_leg': (0, 0, 0, 1, 2, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0),
            'b_leg': (0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 0, 4, 0, 5, 0, 0),
        }
        self.method_dict = {
            'default': ('INVITE', '100', '180', '408', 'ACK'),
            'r_leg': ('INVITE', '100', '302', 'ACK'),
        }

    def generate_flow_sip(self):
        """ Generates an unanswered flow sip from Madrid to Berlin (it looks like somebody is very busy there... :P) """
        print 'Jessi {0} Teles {0} Redir. {0} Pedro'.format(' '*16)
        num_packages = len(self.madrid_to_berlin_call['a_leg'])
        for num in range(num_packages):
            message = '  |'
            for leg in self.leg_list:
                methods = self.method_dict.get(leg, self.method_dict['default'])
                pos = self.madrid_to_berlin_call[leg][num]
                if not(leg == 'r_leg' and self.madrid_to_berlin_call['b_leg'][num]):
                    if pos:
                        method = methods[pos-1]
                        separator = '-'
                    else:
                        method = ''
                        separator = ' '
                    # It might be interesting to document the code below
                    if leg == 'b_leg' and pos:
                        # B Leg is larger than A or Redirect Legs, so separator should appear more times
                        num1 = 10*2 + 2 - int(round(len(method)/2.0, 0))
                        num2 = 10*2 + 1 - len(method)/2
                    else:
                        num1 = 10 - int(round(len(method)/2.0, 0))
                        num2 = 10 - len(method)/2
                    message += '{0} {1} {2}|'.format(separator*num1, method, separator*num2)
            print message
            if num not in (0, num_packages-2):
                time.sleep(1)
        print ''

    def show_message(self):
        """ Shows a farewell message """
        messages = (
            'Hola Pedro!!! Parece que no ha sido posible contactar contigo... jeje :P',
            'Que puedo decirte en este script...?',
            'Si es que despues de todo este tiempo trabajando en StoneWork contigo',
            'es imposible resumir aqui todo lo que he aprendido de ti.',
            'Podria enumerar muchas cosas, porque nos has hecho crecer como equipo en muchos sentidos,',
            'sin embargo, no solo nos has enseñado cosas como profesional, sino tambien como persona.',
            'Gracias por todo ello!!!',
            'Te vamos a echar mucho de menos por aqui!!! :-( Mucha suerte por Berlin!!! ^_^',
        )
        for message in messages:
            print message
            time.sleep(4)
        time.sleep(2)


def run():
    """ Just run functions """
    jessi = Jessi()
    jessi.generate_flow_sip()
    jessi.show_message()


run()



import time
import sys


drawhomero = '''
                                       +--------+
                                      /        /|
                                     /        / |
                                    +--------+  |
                                    |        |  |
                                    |        |  +
                                    |        | /
                                    |        |/
                                    +--------+
                             +
                           +
                         +
                       +
               ,---. 
            ,.'-.   \ 
           ( ( ,'"""""-. 
           `,X          `. 
           /` `           `._ 
          (            ,   ,_\ 
          |          ,---.,'o `. 
          |         / o   \     ) 
           \ ,.    (      .____, 
            \| \    \____,'     \ 
          '`'\  \        _,____,' 
          \  ,--      ,-'     \ 
            ( C     ,'         \ 
             `--'  .'           | 
               |   |         .O | 
             __|    \        ,-'_ 
            / `L     `._  _,'  ' `. 
           /    `--.._  `',.   _\  ` 
           `-.       /\  | `. ( ,\  \ 
          _/  `-._  /  \ |--'  (     \ 
         '  `-.   `'    \/\`.   `.    ) 
               \  -hrr-    \ `.  |    | 



'''

drawpizza = '''
                     )   (    )
                  (    ___  (
                    _.'   `._  )
                _(_____________)___
                pizza dough
'''

drawplay = '''



               _=====_                               _=====_
              / _____ \                             / _____ \
            +.-'_____'-.---------------------------.-'_____'-.+
           /   |     |  '.        S O N Y        .'  |  _  |   \\
          / ___| /|\ |___ \                     / ___| /_\ |___ \\
         / |      |      | ;  __           _   ; | _         _ | ;
         | | <---   ---> | | |__|         |_:> | ||_|       (_)| |
         | |___   |   ___| ;SELECT       START ; |___       ___| ;
         |\    | \|/ |    /  _     ___      _   \    | (X) |    /|
         | \   |_____|  .','" "', |___|  ,'" "', '.  |_____|  .' |
         |  '-.______.-' /       \ANALOG/       \  '-._____.-'   |
         |               |       |------|       |                |
         |              /\       /      \       /\               |
         |             /  '.___.'        '.___.'  \              |
         |            /                            \             |
          \          /                              \           /
           \________/                                \_________/




PUTA BIDA es imposible que salga bien este mando ... :/
'''

drawchao = '''
Un abrazo muy grande.

Also bis bald!
'''
history = [('parra', 'En parte la eleccion de entrar a SWS fue por la entrevista que tuvimos, en ese momento me diste muy buen rollo y por supuesto esa idea acabo siendo cierta. \nNo pude acertar mas!!! Y aqui empece un gran camino, que me ha hecho crecer muchisimo como persona, como trabajador y lo que mas, como informatico, y por supuesto muchisima culpa es tuya.'), ('parra', '\n'), ('time', 15.0), ('parra', 'Los comienzos fueron muy buenos, ese horario de becario no se me olvidara en la vida XD, pero a la par fueron un poco duros:'), ('parra', '\n'), ('time', 4.0), ('parra', drawhomero), ('time', 4.0), ('parra', 'maldito cubo!!! XD. Pero contigo siempre para echar un cable (y mariete que tambien ayudo mucho ), todo se veia de otra manera. '), ('parra', '\n'), ('time', 6.0), ('parra', 'Tampoco olvidare nunca los dias esos, (por suerte pocos XD) que nos toco quedarnos comiendo pizzas en la oficina '), ('time', 6.0), ('parra', drawpizza), ('time', 6.0), ('parra', 'Gracias a uno de esos dias de comer pizza me diste otro libre "para comprarme la play"'), ('parra', '\n'), ('time', 6.0), ('parra', drawplay), ('time', 6.0), ('parra', 'y casi no le hemos dedicado horas eeee XD.'), ('parra', '\n'), ('time', 4.0), ('parra', 'En fin .... , eres una persona de las que deja huella pet!! Me quedo con muchos recuerdos y muy buenos.  Se que todo te ira genial, espero que cuando vuelvas podamos vernos y echarnos unas cervezas. '), ('time', 6.0), ('parra', drawchao), ('time', 6.0)]


## Funcion que no se utiliza
def print_slow(parrafo):
    for letter in parrafo:
        sys.stdout.write(letter)
        time.sleep(.1)


def run():
    for moment in history:
        if moment[0] == 'parra':
            print(moment[1])
        elif moment[0] == 'time':
            time.sleep(moment[1])
    time.sleep(5)

run()



import copy
import os
import random
import time
import struct
import sys


class MediaPrinter(object):

    def center_text(self, fix=0, clear_screen=True):
        if clear_screen:
            self.clear_screen()
        for i in range(self._get_terminal_size_linux()[1]/2-5+fix):
            print('')

    def clear_screen(self):
        os.system('clear')

    def _get_terminal_size_linux(self):  # AKA: funcion patilla que acabo de encontrar en internet
        def ioctl_GWINSZ(fd):
            try:
                import fcntl
                import termios
                cr = struct.unpack('hh', fcntl.ioctl(fd, termios.TIOCGWINSZ, '1234'))
                return cr
            except:
                pass
        cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
        if not cr:
            try:
                fd = os.open(os.ctermid(), os.O_RDONLY)
                cr = ioctl_GWINSZ(fd)
                os.close(fd)
            except:
                pass
        if not cr:
            try:
                cr = (os.environ['LINES'], os.environ['COLUMNS'])
            except:
                return None
        return int(cr[1]), int(cr[0])

    def print_warning(self):
        warning = '''
         _       _____    ____  _   _______   ________
        | |     / /   |  / __ \/ | / /  _/ | / / ____/
        | | /| / / /| | / /_/ /  |/ // //  |/ / / __
        | |/ |/ / ___ |/ _, _/ /|  // // /|  / /_/ /
        |__/|__/_/  |_/_/ |_/_/ |_/___/_/ |_/\____/
        '''
        self.center_text()
        print(warning)
        print('\tDon\'t touch your keyboard during this script (o "Muerte Por Kiki" vendra a por ti..)')

    def print_msg(self):
        msg_ascii = '''
        _|      _|    _|_|        _|_|_|_|_|  _|_|_|_|      _|      _|    _|_|      _|_|_|        _|_|
        _|_|    _|  _|    _|          _|      _|            _|      _|  _|    _|  _|            _|    _|
        _|  _|  _|  _|    _|          _|      _|_|_|        _|      _|  _|_|_|_|    _|_|        _|_|_|_|
        _|    _|_|  _|    _|          _|      _|              _|  _|    _|    _|        _|      _|    _|
        _|      _|    _|_|            _|      _|_|_|_|          _|      _|    _|  _|_|_|        _|    _|


                                                                                                                      _|
        _|        _|_|_|  _|_|_|    _|_|_|      _|_|    _|_|_|        _|_|_|    _|_|_|_|      _|      _|  _|            _|
        _|          _|    _|    _|  _|    _|  _|    _|  _|    _|      _|    _|  _|            _|_|  _|_|          _|    _|
        _|          _|    _|_|_|    _|_|_|    _|_|_|_|  _|_|_|        _|    _|  _|_|_|        _|  _|  _|  _|            _|
        _|          _|    _|    _|  _|    _|  _|    _|  _|    _|      _|    _|  _|            _|      _|  _|            _|
        _|_|_|_|  _|_|_|  _|_|_|    _|    _|  _|    _|  _|    _|      _|_|_|    _|_|_|_|      _|      _|  _|      _|    _|
                                                                                                                      _|
        '''
        self.center_text()
        hours = ['coding', 'futbol (aunque no muchas)', 'pizzas', 'birras', 'burgers', 'play', 'AMISTAD']
        print 'Muchisimas gracias por las horas de trabajo'
        for i, j in enumerate(hours):
            if i == len(hours)-1:
                time.sleep(3)
            else:
                time.sleep(random.random()*2)
            spaces = random.randint(10, 40)
            print('{0}{1}'.format(' '*spaces, j))
        time.sleep(3)
        print('\nPero esto no acaba aqui, seguimos en contacto.')
        time.sleep(5)
        self.center_text()
        print(msg_ascii)
        time.sleep(4)

    def print_europe(self):
        def print_europe_array(europe_map, legend=''):
            center_adjustment = -8
            self.center_text(center_adjustment)
            for line in europe_map:
                for column in line:
                    sys.stdout.write(column)
                    sys.stdout.flush()
                print('')
            for i, l in enumerate(legend):
                if i == len(legend)-1:
                    print('\033[0;93;4m')
                    print(l)
                    print('\033[0m')
                else:
                    print(l)

        def add_point(map, direction, symbol):
            map[direction[1]][direction[0]] = symbol

        def remove_point(map, direction):
            map[direction[1]][direction[0]] = ' '

        europe_ascii = '''
                                -.            .      .-.
                         '       /      / ./
                  _  __,     .--'      / <
                 ~_-~ /     <         <   \_ .-~7
               _. \   >      \.-'\     >`   ~ .-~
              <  ><  /         ,  7   <      ~7
              /_/  ! \       .-L  \  _//   <'~
              ~  .-~  !      ! /o& `' .     7
                 _>_._ >  _.-' '-._.-._.--./
                '-~   ~._/                               .
                  ,-.-'                                  .
                 <                                       .
                  \                                      .
                   7                                ..   .
                   !       _.-.     ..             <  ~v~
            .-~---'   .-.-~    ~\  <  \            /
            )         >      o  <   >  \           \_.--._
           /       .-'      <>   \  \   7       .  '
           7       > . - '        > _\  !   _,-' `.
           ~--,.--'           ._ /.- ~` <   \ .   \\
                              7/ ~       \.,< .  ` `-~-.-~
                                            __  .`


        '''
        madrid = [15, 18]
        berlin = [32, 11]
        europe_map = [[]]
        for e in europe_ascii:
            if e == '\n':
                europe_map.append([])
            else:
                europe_map[-1].append(e)

        legend = []
        legend.append('Europe, Today (hopefully)')
        print_europe_array(europe_map, legend)
        time.sleep(5)
        add_point(europe_map, madrid, 'X')
        legend.append('X - Madrid')
        print_europe_array(europe_map, legend)
        time.sleep(4)
        add_point(europe_map, berlin, '#')
        legend.append('# - Berlin (aprox.. ASCII art sucks!)')
        print_europe_array(europe_map, legend)
        time.sleep(5)
        mario = copy.deepcopy(madrid)
        add_point(europe_map, mario, 'M')
        legend.append('M - It\'s a me! Mario!')
        print_europe_array(europe_map, legend)
        time.sleep(5)
        origin_reshown = False
        while mario != berlin:
            distances = [0, 0]
            for i in range(len(mario)):
                remove_point(europe_map, mario)
                if mario[i] != berlin[i]:
                    mario[i] += 1 if mario[i] < berlin[i] else -1
                    distances[i] = abs(berlin[i] - mario[i])
            try:
                max_axis_distance = (max(distances)/min(distances))
                if max_axis_distance > 2:
                    if distances[0] > distances[1]:
                        axis_to_overincr = 0
                    else:
                        axis_to_overincr = 1
                    mario[axis_to_overincr] += max_axis_distance-1
            except ZeroDivisionError:
                pass
            add_point(europe_map, mario, 'M')
            if not origin_reshown:
                add_point(europe_map, madrid, 'X')
            print_europe_array(europe_map, legend)
            time.sleep(1)
        time.sleep(1)
        legend.append('\nMario: Took me a couple hours!!! Looks like it wasn\'t that far!!! ^^U')
        print_europe_array(europe_map, legend)
        time.sleep(5)
        legend.append('')
        print_europe_array(europe_map, legend)
        print('\033[0;93;4m')
        sys.stdout.write('Pedro: Willkommen Mario')
        sys.stdout.flush()
        time.sleep(0.5)
        sys.stdout.write('.')
        sys.stdout.flush()
        time.sleep(0.4)
        sys.stdout.write('.')
        sys.stdout.flush()
        time.sleep(1)
        sys.stdout.write(' AGAIN -.-')
        sys.stdout.flush()
        print('\033[0m')
        time.sleep(5)
        self.center_text()
        print('Por cierto.. viva el Open Source! Dediquemos unos instantes al creador del mapa original en ascii..')
        time.sleep(4)
        self.center_text()
        print('''
        Peer Wandel Hansen
        - Friday, October 11, 1996 at 04:08:24 (EDT)''')
        time.sleep(0.1)
        self.center_text()
        print('Suficiente.. XD')
        time.sleep(2)

    def call_function_with_timer(self, function, time_after):
        getattr(self, function)()
        time.sleep(time_after)
        self.clear_screen()


def run():
    mp = MediaPrinter()
    mp.call_function_with_timer('print_warning', 3)
    mp.call_function_with_timer('print_europe', 2)
    mp.call_function_with_timer('print_msg', 2)
    mp.center_text()
    print('\tBIS BALD!')
    time.sleep(3)
    print('\t\t\tEl programa ha terminado.. si quieres saber mas de mi.. llamame cojones!')
    time.sleep(1)
    print('\t\t\t\t\t\t\t\t\tPulsa INTRO :)')

run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import time


def run():
    print 'Para las aventuras que puedan acontecerte:'
    time.sleep(5)
    print 'No guardes todo en el mismo Bucket...'
    time.sleep(5)
    print 'Recuerda que Buchannon siempre esta vigilando...'
    time.sleep(5)
    print 'Y MarkFelt tambien...'
    time.sleep(5)
    print 'Cornelius es un nombre feo desde que David mato a Goliath...'
    time.sleep(5)
    print 'pero los nombres feos tienen gancho entre desarrolladores XD'
    time.sleep(5)
    print 'Las cosas claras...'
    time.sleep(3)
    print 'el chocolate espeso...'
    time.sleep(3)
    print 'y el ColaCao.. EN CASA!'
    time.sleep(5)
    print 'Y sobre todo...'
    time.sleep(5)
    print 'mantente alejado de Ms Neumar.'
    time.sleep(5)
    print 'Y para despedir, algo mas emotivo:'
    time.sleep(5)
    print 'Cuando no sea tu mejor dia...'
    time.sleep(5)
    print 'pon a cocer arroz durante dos horas...'
    time.sleep(5)
    print 'veras como se te pasa.'
    time.sleep(3)


run()



from setuptools import setup, find_packages

DIRS_EXCLUDED = ['dist', 'build', 'docs', 'tests']

setup(
    name='swipt',
    packages=find_packages(exclude=DIRS_EXCLUDED),
    version='0.1.1',
    description='StoneWork Is Pedro Ten',
    author='StoneWork Solutions',
    author_email='dev@stoneworksolutions.net',
    url='https://github.com/stoneworksolutions/swipt',
    download_url='https://github.com/stoneworksolutions/swipt/tarball/0.1.1',
    keywords=['swipt', 'pedroten', 'stonework'],
    classifiers=[],
    install_requires=[],
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import pkgutil
import random
import os
import logo
import importlib
import time
import sys


class StoneWorkIsPedroTen(object):
    def __init__(self, *args, **kwargs):
        self.generate_people()
        os.system('clear')
        while True:
            try:
                self.show_menu()
            except (KeyboardInterrupt, EOFError):
                exit(0)

    def generate_people(self):
        people = [name for _, name, _ in pkgutil.iter_modules(['swipt/people'])]
        self.people = sorted(people, key=lambda *args: random.random())

    def load_person(self, person_name):
        self.show_progress('Loading {0}\'s program..'.format(person_name))
        os.system('clear')
        importlib.import_module('swipt.people.{person_name}'.format(person_name=person_name))
        raw_input()
        self.unload_person(person_name)

    def show_menu(self):
        self.show_progress('Loading main menu..')
        os.system('clear')
        self.show_logo()
        self.show_people()
        self.show_selection()

    def show_logo(self):
        print(logo.logo)

    def show_people(self):
        print('Please! Select your friend & colleague :)')
        for i, person in enumerate(self.people):
            print('[{0}] {1}'.format(i, person))
        print('[Q] Quit!')

    def show_selection(self):
        data_ok = False
        while not data_ok:
                try:
                    data = raw_input('Selection: ')
                    data = int(data)
                    data_ok = True
                except ValueError:
                    if data in ('Q', 'q'):
                        exit(0)
                    data_ok = False

        self.load_person(self.people[data])

    def unload_person(self, person_name):
        del sys.modules['swipt.people.{0}'.format(person_name)]

    def show_progress(self, msg):
        i = 0
        sys.stdout.write(msg)
        sys.stdout.flush()
        while i < random.randint(0, 10):
            time.sleep(random.random())
            sys.stdout.write('.')
            sys.stdout.flush()
            i += 1


swipt = StoneWorkIsPedroTen()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import time


def run():

        print("\033[0;30;47m ###### Ahora has decidido cambiar de aires...")
        time.sleep(2)
        print("\033[0;31;47m ###### Porque levantar una empresa de cero ya lo has tachado...")
        time.sleep(2)
        print("\033[0;33;47m ###### Y cuando la gente te pregunte Why?...ya sabes que contestar... ;) \n")
        time.sleep(3)
        print("\033[0;31;47m ###### Gracias por todo lo que nos has ensenado...y no solo de programacion!")
        time.sleep(2)
        print("\033[0;33;47m ###### Pero no te vayas a olvidar de nosotros...")
        time.sleep(2)
        print("\033[0;31;47m ###### Que la vida da muchas vueltas....amigo.")
        time.sleep(3)
        print("\033[0m      Has visto? Ya soy un crack con python!!!!\n")
        time.sleep(2)
        print("Created by Gerard")

run()
